@@ -7,6 +7,8 @@
 #' @return Returns an \eqn{hS x hS} matrix; pair-wise ultrametric-similarity of
 #' historic species.
 #'
+#' @noRd
+#'
 smatrix <-
   function(ps) {
     parameters <- ps$parameters
@@ -41,33 +43,3 @@ smatrix <-
     }
     s_matrix
   }
-
-
-#' descendant_tips
-#'
-#' @param tree object of class \code{phylo}.
-#' @param node object of class \code{numeric}.
-#'
-descendant_tips <- function(tree, node) {
-  x <- node
-  tips <- seq_len(length(tree$tip.label))
-
-  if(node %in% tips) return(node) else {
-    keep <- vector()
-    continue <- TRUE
-
-    while(continue) {
-      check <- tree$edge[which(tree$edge[, 1] %in% x), 2]
-      check
-      daughters <- tips[tips %in% check]
-      daughters
-      keep <- c(keep, daughters)
-      keep
-      x <- check[!check %in% tips]
-      x
-      continue <- ifelse(length(x) != 0, T, F)
-    }
-    return(sort(keep))
-  }
-}
-
