@@ -5,6 +5,8 @@
 #'
 #' @param tax_fac Output of function \code{tax_fac{}}.
 #'
+#' @noRd
+#'
 #' @examples
 #' \dontrun{
 #' # Create Lookup table
@@ -25,9 +27,9 @@ taxid <- function(tax_fac) {
   output <- lapply(seq_along(species), function(x) {
     tmp <- tax_fac[x, ]
     tmp <- lapply(seq_along(tmp), function(y)
-      binaryLogic::as.binary(tmp[y], n = bits[y])) # intToBits(x)
+      as.binary(tmp[y], n = bits[y])) # intToBits(x)
     tmp <- unlist(tmp)
-    tmp <- binaryLogic::as.binary(tmp, logic = TRUE)
+    tmp <- as.binary(tmp, logic = TRUE)
     sum(2 ^ (which(rev(unlist(strsplit(as.character(tmp), "")) == 1)) - 1))
   })
   names(output) <- row.names(tax_fac)
