@@ -2,6 +2,8 @@
 #'
 #' @param lookup Lookup table
 #'
+#' @noRd
+#'
 #' @examples
 #' \dontrun{
 #' # Create Lookup table
@@ -24,7 +26,7 @@ taxmask <- function(lookup) {
     ones <- rep(TRUE, n)
     zeroes <- rep(FALSE, total - n)
     tmp <- c(zeroes, ones)
-    tmp <- binaryLogic::as.binary(tmp, logic = TRUE)
+    tmp <- as.binary(tmp, logic = TRUE)
   })
   names(output) <- colnames(lookup)
   output
